@@ -2,6 +2,7 @@ import os
 import sys
 import glob
 import inspect
+import shutil
 from time import sleep
 
 currentdir = os.path.dirname(os.path.abspath(inspect.getfile(inspect.currentframe())))
@@ -16,19 +17,18 @@ def get_root():
 
 
 def run_tests(generator, root, withdata=False, cpp=True, python=True, php=True, js=True, with_join=False):
-    def run(lang, serialized_format, join_to_one_file=False):
+    def run(lang, serialized_format, join_to_one_file=False, clean_out_dir=True):
         out_directory = root + 'generated_%s' % (lang if lang != 'cpp' else lang + '/' + serialized_format)
 
         # clean python pyc files:
-        def clean_pyc():
-            temp_files = glob.glob(out_directory + '/*.pyc')
-            for filePath in temp_files:
-                try:
-                    os.remove(filePath)
-                except OSError:
-                    pass
+        def clean():
+            try:
+                shutil.rmtree(out_directory)
+            except OSError:
+                pass
 
-        clean_pyc()
+        if clean_out_dir:
+            clean()
         generator.generate(language=lang,
                            out_directory=out_directory,
                            formats=serialized_format,
@@ -39,14 +39,13 @@ def run_tests(generator, root, withdata=False, cpp=True, python=True, php=True,
                                     out_data_directory=root + 'assets')
         generator.run_test(test_script=root + 'test_%s.py' % lang,
                            test_script_args=serialized_format)
-        clean_pyc()
         print('-----------------------------------------')
         print('|  test with params [{}, {}] finished'.format(lang, serialized_format))
         print('-----------------------------------------')
 
     if cpp:
-        run('cpp', 'json')
-        run('cpp', 'xml')
+        run('cpp', 'json', clean_out_dir=False)
+        run('cpp', 'xml', clean_out_dir=False)
     if python:
         run('py', 'json', False)
         run('py', 'xml', False)
