@@ -282,6 +282,8 @@ def get_cpp(with_ctr):
 #include "mg_Factory.h"
 #include "Test.h"
 #include "mg_extensions.h"
+#include "SerializerJson.h"
+#include "SerializerXml.h"
 
 namespace mg
 {
@@ -332,12 +334,17 @@ def get_hpp():
     return '''#ifndef __mg_Test_h__
 #define __mg_Test_h__
 
+#include <cstdint>
 #include "intrusive_ptr.h"
 #include "pugixml/pugixml.hpp"
 #include <string>
 
 namespace mg
 {
+    class SerializerXml;
+    class DeserializerXml;
+    class SerializerJson;
+    class DeserializerJson;
 
     class Test
     {
